@@ -1,14 +1,19 @@
 import asyncio
 import logging
 import logging.config
+import pathlib
+from typing import Any
 
 from wi1_bot import webhook
+from wi1_bot.config import config
 from wi1_bot.discord import bot
 from wi1_bot.transcoder import Transcoder
 
+_logger = logging.getLogger(__name__)
+
 
 def main() -> None:
-    logging_config = {
+    logging_config: dict[str, Any] = {
         "version": 1,
         "disable_existing_loggers": True,
         "formatters": {
@@ -32,22 +37,6 @@ def main() -> None:
                 "level": "DEBUG",
                 "formatter": "detailed",
             },
-            # "file": {
-            #     "class": "logging.handlers.RotatingFileHandler",
-            #     "filename": "logs/wi1-bot.log",
-            #     "maxBytes": 1024**2 * 10,  # 10 MB
-            #     "backupCount": 20,
-            #     "level": "INFO",
-            #     "formatter": "basic",
-            # },
-            # "file_debug": {
-            #     "class": "logging.handlers.RotatingFileHandler",
-            #     "filename": "logs/wi1-bot.debug.log",
-            #     "maxBytes": 1024**2 * 10,  # 10 MB
-            #     "backupCount": 20,
-            #     "level": "DEBUG",
-            #     "formatter": "detailed",
-            # },
         },
         "loggers": {
             "": {"level": "DEBUG", "handlers": ["console"]},
@@ -55,8 +44,35 @@ def main() -> None:
         },
     }
 
+    log_dir: pathlib.Path | None = None
+
+    if "general" in config and "log_dir" in config["general"]:
+        log_dir = pathlib.Path(config["general"]["log_dir"]).resolve()
+
+        logging_config["handlers"]["file"] = {
+            "class": "logging.handlers.RotatingFileHandler",
+            "filename": str(log_dir / "wi1-bot.log"),
+            "maxBytes": 1024**2 * 10,  # 10 MB
+            "backupCount": 100,
+            "level": "INFO",
+            "formatter": "basic",
+        }
+
+        logging_config["handlers"]["file_debug"] = {
+            "class": "logging.handlers.RotatingFileHandler",
+            "filename": str(log_dir / "wi1-bot.debug.log"),
+            "maxBytes": 1024**2 * 10,  # 10 MB
+            "backupCount": 20,
+            "level": "DEBUG",
+            "formatter": "detailed",
+        }
+
+        logging_config["loggers"][""]["handlers"].extend(["file", "file_debug"])
+
     logging.config.dictConfig(logging_config)
 
+    _logger.info(f"logging to: {log_dir}")
+
     webhook.start()
 
     t = Transcoder()
