@@ -6,6 +6,7 @@ import subprocess
 import threading
 from datetime import timedelta
 from time import sleep
+from typing import Any
 
 from wi1_bot import push
 from wi1_bot.arr import Radarr, Sonarr
@@ -30,7 +31,7 @@ class Transcoder:
         self.sonarr = Sonarr(config["sonarr"]["url"], config["sonarr"]["api_key"])
 
     def start(self) -> None:
-        self.logger.debug("starting transcoder")
+        self.logger.info("starting transcoder")
 
         t = threading.Thread(target=self._worker)
         t.daemon = True
@@ -124,6 +125,13 @@ class Transcoder:
                     raise SignalInterrupt
 
                 perm_log_path = tmp_folder / f"{path.stem}.log"
+
+                if "general" in config and "log_dir" in config["general"]:
+                    log_dir = pathlib.Path(config["general"]["log_dir"]).resolve()
+
+                    perm_log_path = log_dir / "transcoder-errors" / f"{path.stem}.log"
+                    perm_log_path.parent.mkdir(parents=True, exist_ok=True)
+
                 shutil.copy(tmp_log_path, perm_log_path)
                 self.logger.error(f"log file: {perm_log_path}")
 
@@ -189,7 +197,7 @@ class Transcoder:
     def _build_ffmpeg_command(
         self, item: TranscodeItem, transcode_to: pathlib.Path
     ) -> list[str]:
-        command = [
+        command: list[Any] = [
             "ffmpeg",
             "-hide_banner",
             "-y",
@@ -201,44 +209,63 @@ class Transcoder:
         except KeyError:
             pass
 
+        command.extend(["-probesize", "100M"])
+        command.extend(["-analyzeduration", "250M"])
+
         command.extend(["-i", item.path])
 
+        langs: list[str] = []
+
+        if item.languages:
+            langs = item.languages.split(",")
+
+        # TODO: use ffprobe to figure out what streams we should copy
+        # always copy first video stream
+        # always copy first audio stream
+        # always copy all subtitle streams
+        # if languages is specified in the config:
+        #     copy all audio streams in one of those languages
+        # ffprobe -show_streams -print_format json {input_file} 2>/dev/null
         if item.copy_all_streams:
             command.extend(["-map", "0"])
+        else:
+            command.extend(["-map", "0:v:0"])
+
+            command.extend(["-map", "0:a:0?"])
+
+            if langs:
+                command.extend([["-map", f"0:s:m:language:{lang}?"] for lang in langs])
+            else:
+                command.extend(["-map", "0:s?"])
 
         if item.video_codec:
-            command.extend(
-                ["-c:v", item.video_codec, "-preset", "fast", "-profile:v", "main"]
-            )
+            command.extend(["-vcodec", item.video_codec])
+            command.extend(["-preset", "fast"])
+            command.extend(["-profile:v", "main"])
         else:
-            command.extend(["-c:v", "copy"])
+            command.extend(["-vcodec", "copy"])
 
         if item.video_bitrate:
-            command.extend(
-                [
-                    "-b:v",
-                    str(item.video_bitrate),
-                    "-maxrate",
-                    str(item.video_bitrate * 2),
-                    "-bufsize",
-                    str(item.video_bitrate * 2),
-                ]
-            )
+            command.extend(["-b:v", item.video_bitrate])
+            command.extend(["-maxrate", item.video_bitrate * 2])
+            command.extend(["-bufsize", item.video_bitrate * 2])
 
         if item.audio_codec:
-            command.extend(["-c:a", item.audio_codec])
+            command.extend(["-acodec", item.audio_codec])
         else:
-            command.extend(["-c:a", "copy"])
+            command.extend(["-acodec", "copy"])
 
         if item.audio_channels:
-            command.extend(["-ac", str(item.audio_channels)])
+            command.extend(["-ac", item.audio_channels])
 
         if item.audio_bitrate:
-            command.extend(["-b:a", str(item.audio_bitrate)])
+            command.extend(["-b:a", item.audio_bitrate])
 
-        command.extend(["-c:s", "copy", str(transcode_to)])
+        command.extend(["-scodec", "copy"])
 
-        return command
+        command.extend([transcode_to])
+
+        return [str(arg) for arg in command]
 
 
 if __name__ == "__main__":
