@@ -1,13 +1,14 @@
+import json
 import logging
-import os.path
+import pathlib
 import threading
-from typing import Any, cast
+from typing import Any
 
 from flask import Flask, request
 
 from wi1_bot import push, transcoder
 from wi1_bot.arr import Radarr, Sonarr
-from wi1_bot.config import config
+from wi1_bot.config import RemotePathMapping, config
 
 app = Flask(__name__)
 
@@ -25,40 +26,78 @@ def on_grab(req: dict[str, Any]) -> None:
     )
 
 
+def replace_remote_paths(path: pathlib.Path) -> pathlib.Path:
+    if "general" not in config or "remote_path_mappings" not in config["general"]:
+        return path
+
+    mappings = config["general"]["remote_path_mappings"]
+
+    most_specific: RemotePathMapping | None = None
+
+    for mapping in mappings:
+        if path.is_relative_to(mapping["remote"]):
+            mapping_len = len(pathlib.Path(mapping["remote"]).parts)
+            most_specific_len = (
+                len(pathlib.Path(most_specific["remote"]).parts)
+                if most_specific is not None
+                else 0
+            )
+
+            if mapping_len > most_specific_len:
+                most_specific = mapping
+
+    if most_specific is not None:
+        remote_path = path
+        path = pathlib.Path(most_specific["local"]) / path.relative_to(
+            most_specific["remote"]
+        )
+
+        logger.debug(f"replaced remote path mapping: {remote_path} -> {path}")
+
+    return path
+
+
 def on_download(req: dict[str, Any]) -> None:
+    path: pathlib.Path
+    content_id: int
+
     if "movie" in req:
         content_id = req["movie"]["id"]
+        movie_json = radarr._radarr.get_movie(content_id)
+        assert isinstance(movie_json, dict)
 
         quality_profile = radarr.get_quality_profile_name(
-            cast(dict[str, Any], radarr._radarr.get_movie_by_movie_id(content_id))[
-                "qualityProfileId"
-            ]
+            movie_json["qualityProfileId"]
         )
 
         movie_folder = req["movie"]["folderPath"]
-        basename = req["movieFile"]["relativePath"]
+        relative_path = req["movieFile"]["relativePath"]
 
-        push.send(basename, title="movie downloaded")
+        path = pathlib.Path(movie_folder) / relative_path
 
-        path = os.path.join(movie_folder, basename)
+        if not req["isUpgrade"]:
+            push.send(path.name, title="new movie downloaded")
     elif "series" in req:
         content_id = req["series"]["id"]
+        series_json = sonarr._sonarr.get_series(content_id)
+        assert isinstance(series_json, dict)
 
         quality_profile = sonarr.get_quality_profile_name(
-            cast(dict[str, Any], sonarr._sonarr.get_series(content_id))[
-                "qualityProfileId"
-            ]
+            series_json["qualityProfileId"]
         )
 
         series_folder = req["series"]["path"]
         relative_path = req["episodeFile"]["relativePath"]
 
-        push.send(relative_path.split("/")[-1], title="episode downloaded")
+        path = pathlib.Path(series_folder) / relative_path
 
-        path = os.path.join(series_folder, relative_path)
+        if not req["isUpgrade"]:
+            push.send(path.name, title="new episode downloaded")
     else:
         raise ValueError("unknown download request")
 
+    path = replace_remote_paths(path)
+
     try:
         quality_options = config["transcoding"]["profiles"][quality_profile]
     except KeyError:
@@ -72,7 +111,7 @@ def on_download(req: dict[str, Any]) -> None:
             return None
 
     copy_all_streams = get_key(quality_options, "copy_all_streams")
-
+    languages = get_key(quality_options, "languages")
     video_codec = get_key(quality_options, "video_codec")
     video_bitrate = get_key(quality_options, "video_bitrate")
     audio_codec = get_key(quality_options, "audio_codec")
@@ -80,14 +119,15 @@ def on_download(req: dict[str, Any]) -> None:
     audio_bitrate = get_key(quality_options, "audio_bitrate")
 
     transcoder.queue.add(
-        path=path,
+        path=str(path),
+        content_id=content_id,
         copy_all_streams=copy_all_streams,
+        languages=languages,
         video_codec=video_codec,
         video_bitrate=video_bitrate,
         audio_codec=audio_codec,
         audio_channels=audio_channels,
         audio_bitrate=audio_bitrate,
-        content_id=content_id,
     )
 
 
@@ -97,11 +137,9 @@ def index() -> Any:
         if request.json is None or "eventType" not in request.json:
             return "", 400
 
-        logger.debug(f"got request: {request.json}")
+        logger.debug(f"got request: {json.dumps(request.json)}")
 
-        if request.json["eventType"] == "Grab":
-            on_grab(request.json)
-        elif request.json["eventType"] == "Download":
+        if request.json["eventType"] == "Download":
             on_download(request.json)
     except Exception:
         logger.warning(
@@ -112,12 +150,12 @@ def index() -> Any:
 
 
 def start() -> None:
-    logger.debug("starting webhook listener")
+    logger.info("starting webhook listener")
 
-    t = threading.Thread(target=app.run, kwargs={"host": "localhost", "port": 9000})
+    t = threading.Thread(target=app.run, kwargs={"host": "0.0.0.0", "port": 9000})
     t.daemon = True
     t.start()
 
 
 if __name__ == "__main__":
-    app.run(host="localhost", port=9000)
+    app.run(host="0.0.0.0", port=9000)
